summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/msn/msncontact.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:51 -0600
commit089118c18533dfa3e6ce5065dbebdd4db94051f1 (patch)
treece014fb2326a80fcfafa2362b7ff88486aa17c96 /kopete/protocols/msn/msncontact.cpp
parent83677e35509b4dafac63b76995652bdf3b49f209 (diff)
downloadtdenetwork-089118c18533dfa3e6ce5065dbebdd4db94051f1.tar.gz
tdenetwork-089118c18533dfa3e6ce5065dbebdd4db94051f1.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kopete/protocols/msn/msncontact.cpp')
-rw-r--r--kopete/protocols/msn/msncontact.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kopete/protocols/msn/msncontact.cpp b/kopete/protocols/msn/msncontact.cpp
index 304029bf..0b38f2c3 100644
--- a/kopete/protocols/msn/msncontact.cpp
+++ b/kopete/protocols/msn/msncontact.cpp
@@ -89,7 +89,7 @@ MSNContact::~MSNContact()
bool MSNContact::isReachable()
{
- if ( account()->isConnected() && isOnline() && account()->myself()->onlinetqStatus() != MSNProtocol::protocol()->HDN )
+ if ( account()->isConnected() && isOnline() && account()->myself()->onlineStatus() != MSNProtocol::protocol()->HDN )
return true;
MSNChatSession *kmm=dynamic_cast<MSNChatSession*>(manager(Kopete::Contact::CannotCreate));
@@ -98,13 +98,13 @@ bool MSNContact::isReachable()
// When we are invisible we can't start a chat with others, make isReachable return false
// (This is an MSN limitation, not a problem in Kopete)
- if ( !account()->isConnected() || account()->myself()->onlinetqStatus() == MSNProtocol::protocol()->HDN )
+ if ( !account()->isConnected() || account()->myself()->onlineStatus() == MSNProtocol::protocol()->HDN )
return false;
//if the contact is offline, it is impossible to send it a message. but it is impossible
//to be sure the contact is realy offline. For example, if the contact is not on the contactlist for
//some reason.
- if( onlinetqStatus() == MSNProtocol::protocol()->FLN && ( isAllowed() || isBlocked() ) && !serverGroups().isEmpty() )
+ if( onlineStatus() == MSNProtocol::protocol()->FLN && ( isAllowed() || isBlocked() ) && !serverGroups().isEmpty() )
return false;
return true;
@@ -264,8 +264,8 @@ void MSNContact::setBlocked( bool blocked )
{
m_blocked = blocked;
//update the status
- setOnlineStatus(m_currenttqStatus);
- //m_currenttqStatus is used here. previously it was onlinetqStatus() but this may cause problem when
+ setOnlineStatus(m_currentStatus);
+ //m_currentStatus is used here. previously it was onlineStatus() but this may cause problem when
// the account is offline because of the Kopete::Contact::OnlineStatus() account offline hack.
}
}
@@ -577,7 +577,7 @@ void MSNContact::rename( const TQString &newName )
void MSNContact::slotShowProfile()
{
- KRun::runURL( KURL( TQString::tqfromLatin1("http://members.msn.com/?pgmarket=it-it&mem=") + contactId()) , "text/html" );
+ KRun::runURL( KURL( TQString::fromLatin1("http://members.msn.com/?pgmarket=it-it&mem=") + contactId()) , "text/html" );
}
@@ -655,7 +655,7 @@ void MSNContact::setOnlineStatus(const Kopete::OnlineStatus& status)
}
else
Kopete::Contact::setOnlineStatus(status);
- m_currenttqStatus=status;
+ m_currentStatus=status;
}
void MSNContact::slotSendMail()
@@ -703,7 +703,7 @@ void MSNContact::setObject(const TQString &obj)
KConfig *config = KGlobal::config();
config->setGroup( "MSN" );
if ( config->readNumEntry( "DownloadPicture", 2 ) >= 2 && !obj.isEmpty()
- && account()->myself()->onlinetqStatus().status() != Kopete::OnlineStatus::Invisible )
+ && account()->myself()->onlineStatus().status() != Kopete::OnlineStatus::Invisible )
manager(Kopete::Contact::CanCreate); //create the manager which will download the photo automatically.
}